@@ -314,3 +314,27 @@ def VariationalDropout(dropout_rate: float, seed=SentinelValueForAutoSelectRando
         return mask * x
 
     return inner
+
+
+def SequenceDropout(dropout_rate: float, seed=SentinelValueForAutoSelectRandomSeed, name=''):
+    """ Completely mask some sequence elements with zeros.
+    This is different from normal dropout where there dimensions of the static axis have some probably of being zero-ed.
+
+    Arguments:
+        dropout_rate (float): probability of dropping out (i.e. zero out) an entire sequence element
+        seed (int): seed for randomisation
+        name (str, defaults to ''): the name of the Function instance in the network
+
+    Returns:
+        cntk.ops.functions.Function:
+        A function that accepts one argument and applies the operation to it
+
+    """
+    dropout = C.layers.Dropout(dropout_rate, seed=seed)
+
+    @C.BlockFunction('SequenceDropout', name)
+    def inner(x):
+        mask = dropout(C.sequence.broadcast_as(1 / dropout_rate, x))
+        return mask * x
+
+    return inner
